==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/solutions/kotlin/inputs/ApplicationPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.solutions.kotlin.inputs

import com.pulumi.azurenative.solutions.inputs.ApplicationPolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Managed application policy.
 * @property name The policy name
 * @property parameters The policy parameters.
 * @property policyDefinitionId The policy definition Id.
 */
public data class ApplicationPolicyArgs(
    public val name: Output<String>? = null,
    public val parameters: Output<String>? = null,
    public val policyDefinitionId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.solutions.inputs.ApplicationPolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.solutions.inputs.ApplicationPolicyArgs =
        com.pulumi.azurenative.solutions.inputs.ApplicationPolicyArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .parameters(parameters?.applyValue({ args0 -> args0 }))
            .policyDefinitionId(policyDefinitionId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ApplicationPolicyArgs].
 */
@PulumiTagMarker
public class ApplicationPolicyArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var parameters: Output<String>? = null

    private var policyDefinitionId: Output<String>? = null

    /**
     * @param value The policy name
     */
    @JvmName("ahwslukatxpalpug")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The policy parameters.
     */
    @JvmName("wxxepwaqbsjhrinl")
    public suspend fun parameters(`value`: Output<String>) {
        this.parameters = value
    }

    /**
     * @param value The policy definition Id.
     */
    @JvmName("abpmesaowjpliedy")
    public suspend fun policyDefinitionId(`value`: Output<String>) {
        this.policyDefinitionId = value
    }

    /**
     * @param value The policy name
     */
    @JvmName("etiwuonrxbsmakmy")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The policy parameters.
     */
    @JvmName("xhmpxmrndsruqjon")
    public suspend fun parameters(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.parameters = mapped
    }

    /**
     * @param value The policy definition Id.
     */
    @JvmName("srceqxdqfyottbyd")
    public suspend fun policyDefinitionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.policyDefinitionId = mapped
    }

    internal fun build(): ApplicationPolicyArgs = ApplicationPolicyArgs(
        name = name,
        parameters = parameters,
        policyDefinitionId = policyDefinitionId,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/solutions/kotlin/inputs/ApplicationPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.solutions.kotlin.inputs

import com.pulumi.azurenative.solutions.inputs.ApplicationPolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Managed application policy.
 * @property name The policy name
 * @property parameters The policy parameters.
 * @property policyDefinitionId The policy definition Id.
 */
public data class ApplicationPolicyArgs(
    public val name: Output<String>? = null,
    public val parameters: Output<String>? = null,
    public val policyDefinitionId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.solutions.inputs.ApplicationPolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.solutions.inputs.ApplicationPolicyArgs =
        com.pulumi.azurenative.solutions.inputs.ApplicationPolicyArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .parameters(parameters?.applyValue({ args0 -> args0 }))
            .policyDefinitionId(policyDefinitionId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ApplicationPolicyArgs].
 */
@PulumiTagMarker
public class ApplicationPolicyArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var parameters: Output<String>? = null

    private var policyDefinitionId: Output<String>? = null

    /**
     * @param value The policy name
     */
    @JvmName("attwjxwfkbffbcwc")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The policy parameters.
     */
    @JvmName("cplmmuotmdrngtlu")
    public suspend fun parameters(`value`: Output<String>) {
        this.parameters = value
    }

    /**
     * @param value The policy definition Id.
     */
    @JvmName("lscxankursawbdsa")
    public suspend fun policyDefinitionId(`value`: Output<String>) {
        this.policyDefinitionId = value
    }

    /**
     * @param value The policy name
     */
    @JvmName("qfqvixpxgjlebrbf")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The policy parameters.
     */
    @JvmName("momapkwgrqvlnpfj")
    public suspend fun parameters(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.parameters = mapped
    }

    /**
     * @param value The policy definition Id.
     */
    @JvmName("bryweklqlutbjdia")
    public suspend fun policyDefinitionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.policyDefinitionId = mapped
    }

    internal fun build(): ApplicationPolicyArgs = ApplicationPolicyArgs(
        name = name,
        parameters = parameters,
        policyDefinitionId = policyDefinitionId,
    )
}
